pub enum SerializeSdf<'a, V: Point> {
Generic(SerializeGeneric<'a, V>),
Grid(SerializeGrid<'a, V>),
}Expand description
Serialize signed distance fields struct.
Variants
Generic(SerializeGeneric<'a, V>)
Serialize a generic signed distance fields computed with generate_sdf.
Grid(SerializeGrid<'a, V>)
Serialize a grid signed distance fields computed with generate_grid_sdf.